# Topping

##### Topping is a Python library for tracking function data.  

<br/>
<br/>

## Installation


```
pip install topping
```

<br/>
<br/>

## Usage

### Add `@topping` decorator to the function you want to track.

<br/>

![example1](https://user-images.githubusercontent.com/123562684/215257570-9c53ed47-dfcc-4d56-b98d-af8ed2b3d035.png)

<br/>
<br/>

### The output will be something like:

<br/>

<img width="1200" alt="example1_result" src="https://user-images.githubusercontent.com/123562684/215257227-e607af35-2ffa-4c85-a4b8-1832da8301da.png">

<br/>
<br/>
<br/>
<br/>
<br/>
<br/>

### Topping also helps when error occurs
<br/>

![example3](https://user-images.githubusercontent.com/123562684/215257524-f985af60-990d-410f-903d-33ea9618c454.png)
<br/>
<br/>

<img width="1200" alt="example3_result" src="https://user-images.githubusercontent.com/123562684/215257529-5849abd2-6b72-4b79-8b72-4742dd00af52.png">


<br/>
<br/>


## License


MIT LISENCE
